from pkgcheck import addons, base, feeds, reporters
from pkgcheck.checks import acct, cleanup, codingstyle, deprecated, dropped_keywords, git, glsa, imlate, metadata, metadata_xml, network, overlays, pkgdir, profiles, python, repo, repo_metadata, stablereq, unstable_only, visibility, whitespace
KEYWORDS = (('ConflictingAccountIdentifiers', acct.ConflictingAccountIdentifiers), ('MissingAccountIdentifier', acct.MissingAccountIdentifier), ('OutsideRangeAccountIdentifier', acct.OutsideRangeAccountIdentifier), ('RedundantVersion', cleanup.RedundantVersion), ('AbsoluteSymlink', codingstyle.AbsoluteSymlink), ('BadInsIntoDir', codingstyle.BadInsIntoDir), ('BannedEapiCommand', codingstyle.BannedEapiCommand), ('DeprecatedEapiCommand', codingstyle.DeprecatedEapiCommand), ('DoublePrefixInPath', codingstyle.DoublePrefixInPath), ('HomepageInSrcUri', codingstyle.HomepageInSrcUri), ('HttpsAvailable', codingstyle.HttpsAvailable), ('InvalidCopyright', codingstyle.InvalidCopyright), ('InvalidLicenseHeader', codingstyle.InvalidLicenseHeader), ('MissingSlash', codingstyle.MissingSlash), ('NonGentooAuthorsCopyright', codingstyle.NonGentooAuthorsCopyright), ('ObsoleteUri', codingstyle.ObsoleteUri), ('OldGentooCopyright', codingstyle.OldGentooCopyright), ('PortageInternals', codingstyle.PortageInternals), ('UnnecessarySlashStrip', codingstyle.UnnecessarySlashStrip), ('DeprecatedEclass', deprecated.DeprecatedEclass), ('DroppedKeywords', dropped_keywords.DroppedKeywords), ('BadCommitSummary', git.BadCommitSummary), ('DirectNoMaintainer', git.DirectNoMaintainer), ('DirectStableKeywords', git.DirectStableKeywords), ('DroppedStableKeywords', git.DroppedStableKeywords), ('DroppedUnstableKeywords', git.DroppedUnstableKeywords), ('MissingSignOff', git.MissingSignOff), ('OutdatedCopyright', git.OutdatedCopyright), ('VulnerablePackage', glsa.VulnerablePackage), ('LaggingStable', imlate.LaggingStable), ('PotentialStable', imlate.PotentialStable), ('BadDescription', metadata.BadDescription), ('BadFilename', metadata.BadFilename), ('BadHomepage', metadata.BadHomepage), ('BadProtocol', metadata.BadProtocol), ('BadRestricts', metadata.BadRestricts), ('BannedEAPI', metadata.BannedEAPI), ('DeprecatedEAPI', metadata.DeprecatedEAPI), ('DuplicateKeywords', metadata.DuplicateKeywords), ('InvalidKeywords', metadata.InvalidKeywords), ('InvalidUseFlags', metadata.InvalidUseFlags), ('MatchingGlobalUSE', metadata.MatchingGlobalUSE), ('MetadataError', base.MetadataError), ('MissingLicense', metadata.MissingLicense), ('MissingLicenseRestricts', metadata.MissingLicenseRestricts), ('MissingPackageRevision', metadata.MissingPackageRevision), ('MissingSlotDep', metadata.MissingSlotDep), ('MissingTestRestrict', metadata.MissingTestRestrict), ('MissingUnpackerDep', metadata.MissingUnpackerDep), ('MissingUri', metadata.MissingUri), ('MissingUseDepDefault', metadata.MissingUseDepDefault), ('MissingVirtualKeywords', metadata.MissingVirtualKeywords), ('NonexistentBlocker', metadata.NonexistentBlocker), ('OutdatedBlocker', metadata.OutdatedBlocker), ('OverlappingKeywords', metadata.OverlappingKeywords), ('ProbableGlobalUSE', metadata.ProbableGlobalUSE), ('ProbableUseExpand', metadata.ProbableUseExpand), ('RequiredUseDefaults', metadata.RequiredUseDefaults), ('StupidKeywords', metadata.StupidKeywords), ('TarballAvailable', metadata.TarballAvailable), ('UnderscoreInUseFlag', metadata.UnderscoreInUseFlag), ('UnknownMirror', metadata.UnknownMirror), ('UnknownProperties', metadata.UnknownProperties), ('UnknownUseFlags', metadata.UnknownUseFlags), ('UnnecessaryLicense', metadata.UnnecessaryLicense), ('UnsortedKeywords', metadata.UnsortedKeywords), ('UnstatedIUSE', addons.UnstatedIUSE), ('UnusedLocalUSE', metadata.UnusedLocalUSE), ('CatBadlyFormedXml', metadata_xml.CatBadlyFormedXml), ('CatInvalidXml', metadata_xml.CatInvalidXml), ('CatMetadataXmlEmptyElement', metadata_xml.CatMetadataXmlEmptyElement), ('CatMetadataXmlIndentation', metadata_xml.CatMetadataXmlIndentation), ('CatMetadataXmlInvalidCatRef', metadata_xml.CatMetadataXmlInvalidCatRef), ('CatMetadataXmlInvalidPkgRef', metadata_xml.CatMetadataXmlInvalidPkgRef), ('CatMissingMetadataXml', metadata_xml.CatMissingMetadataXml), ('EmptyMaintainer', metadata_xml.EmptyMaintainer), ('MaintainerWithoutProxy', metadata_xml.MaintainerWithoutProxy), ('NonexistentProjectMaintainer', metadata_xml.NonexistentProjectMaintainer), ('PkgBadlyFormedXml', metadata_xml.PkgBadlyFormedXml), ('PkgInvalidXml', metadata_xml.PkgInvalidXml), ('PkgMetadataXmlEmptyElement', metadata_xml.PkgMetadataXmlEmptyElement), ('PkgMetadataXmlIndentation', metadata_xml.PkgMetadataXmlIndentation), ('PkgMetadataXmlInvalidCatRef', metadata_xml.PkgMetadataXmlInvalidCatRef), ('PkgMetadataXmlInvalidPkgRef', metadata_xml.PkgMetadataXmlInvalidPkgRef), ('PkgMissingMetadataXml', metadata_xml.PkgMissingMetadataXml), ('StaleProxyMaintProject', metadata_xml.StaleProxyMaintProject), ('WrongMaintainerType', metadata_xml.WrongMaintainerType), ('DeadHomepage', network.DeadHomepage), ('DeadSrcUrl', network.DeadSrcUrl), ('HttpsUrlAvailable', network.HttpsUrlAvailable), ('RedirectedHomepage', network.RedirectedHomepage), ('RedirectedSrcUrl', network.RedirectedSrcUrl), ('SSLCertificateError', network.SSLCertificateError), ('UnusedInMastersEclasses', overlays.UnusedInMastersEclasses), ('UnusedInMastersGlobalUSE', overlays.UnusedInMastersGlobalUSE), ('UnusedInMastersLicenses', overlays.UnusedInMastersLicenses), ('UnusedInMastersMirrors', overlays.UnusedInMastersMirrors), ('DuplicateFiles', pkgdir.DuplicateFiles), ('EmptyFile', pkgdir.EmptyFile), ('EqualVersions', pkgdir.EqualVersions), ('ExecutableFile', pkgdir.ExecutableFile), ('Glep31Violation', pkgdir.Glep31Violation), ('InvalidPN', pkgdir.InvalidPN), ('InvalidUTF8', pkgdir.InvalidUTF8), ('MismatchedPN', pkgdir.MismatchedPN), ('SizeViolation', pkgdir.SizeViolation), ('UnknownFile', pkgdir.UnknownFile), ('ArchesWithoutProfiles', profiles.ArchesWithoutProfiles), ('BadProfileEntry', profiles.BadProfileEntry), ('LaggingProfileEAPI', profiles.LaggingProfileEAPI), ('NonexistentProfilePath', profiles.NonexistentProfilePath), ('ProfileError', profiles.ProfileError), ('ProfileWarning', profiles.ProfileWarning), ('UnknownCategories', profiles.UnknownCategories), ('UnknownProfilePackageKeywords', profiles.UnknownProfilePackageKeywords), ('UnknownProfilePackageUse', profiles.UnknownProfilePackageUse), ('UnknownProfilePackages', profiles.UnknownProfilePackages), ('UnknownProfileUse', profiles.UnknownProfileUse), ('UnusedProfileDirs', profiles.UnusedProfileDirs), ('MissingPythonEclass', python.MissingPythonEclass), ('PythonMissingDeps', python.PythonMissingDeps), ('PythonMissingRequiredUSE', python.PythonMissingRequiredUSE), ('PythonRuntimeDepInAnyR1', python.PythonRuntimeDepInAnyR1), ('PythonSingleUseMismatch', python.PythonSingleUseMismatch), ('BinaryFile', repo.BinaryFile), ('BadPackageUpdate', repo_metadata.BadPackageUpdate), ('ConflictingChksums', repo_metadata.ConflictingChksums), ('DeprecatedChksum', repo_metadata.DeprecatedChksum), ('MissingChksum', repo_metadata.MissingChksum), ('MissingManifest', repo_metadata.MissingManifest), ('MovedPackageUpdate', repo_metadata.MovedPackageUpdate), ('MultiMovePackageUpdate', repo_metadata.MultiMovePackageUpdate), ('OldMultiMovePackageUpdate', repo_metadata.OldMultiMovePackageUpdate), ('OldPackageUpdate', repo_metadata.OldPackageUpdate), ('PotentialGlobalUSE', repo_metadata.PotentialGlobalUSE), ('PotentialLocalUSE', repo_metadata.PotentialLocalUSE), ('UnknownLicenses', repo_metadata.UnknownLicenses), ('UnknownManifest', repo_metadata.UnknownManifest), ('UnnecessaryManifest', repo_metadata.UnnecessaryManifest), ('UnusedEclasses', repo_metadata.UnusedEclasses), ('UnusedGlobalUSE', repo_metadata.UnusedGlobalUSE), ('UnusedLicenses', repo_metadata.UnusedLicenses), ('UnusedMirrors', repo_metadata.UnusedMirrors), ('StableRequest', stablereq.StableRequest), ('UnstableOnly', unstable_only.UnstableOnly), ('NonexistentDeps', visibility.NonexistentDeps), ('NonsolvableDepsInDev', visibility.NonsolvableDepsInDev), ('NonsolvableDepsInExp', visibility.NonsolvableDepsInExp), ('NonsolvableDepsInStable', visibility.NonsolvableDepsInStable), ('UncheckableDep', visibility.UncheckableDep), ('VisibleVcsPkg', visibility.VisibleVcsPkg), ('DoubleEmptyLine', whitespace.DoubleEmptyLine), ('NoFinalNewline', whitespace.NoFinalNewline), ('TrailingEmptyLine', whitespace.TrailingEmptyLine), ('WhitespaceFound', whitespace.WhitespaceFound), ('WrongIndentFound', whitespace.WrongIndentFound))
CHECKS = (('AcctCheck', acct.AcctCheck), ('RedundantVersionCheck', cleanup.RedundantVersionCheck), ('AbsoluteSymlinkCheck', codingstyle.AbsoluteSymlinkCheck), ('BadCommandsCheck', codingstyle.BadCommandsCheck), ('BadInsIntoCheck', codingstyle.BadInsIntoCheck), ('EbuildHeaderCheck', codingstyle.EbuildHeaderCheck), ('HomepageInSrcUriCheck', codingstyle.HomepageInSrcUriCheck), ('HttpsAvailableCheck', codingstyle.HttpsAvailableCheck), ('ObsoleteUriCheck', codingstyle.ObsoleteUriCheck), ('PathVariablesCheck', codingstyle.PathVariablesCheck), ('DeprecatedEclassCheck', deprecated.DeprecatedEclassCheck), ('DroppedKeywordsCheck', dropped_keywords.DroppedKeywordsCheck), ('GitCommitsCheck', git.GitCommitsCheck), ('GitPkgCommitsCheck', git.GitPkgCommitsCheck), ('GlsaCheck', glsa.GlsaCheck), ('ImlateCheck', imlate.ImlateCheck), ('DependencyCheck', metadata.DependencyCheck), ('DescriptionCheck', metadata.DescriptionCheck), ('HomepageCheck', metadata.HomepageCheck), ('IUSEMetadataCheck', metadata.IUSEMetadataCheck), ('KeywordsCheck', metadata.KeywordsCheck), ('LicenseMetadataCheck', metadata.LicenseMetadataCheck), ('LocalUSECheck', metadata.LocalUSECheck), ('MetadataCheck', metadata.MetadataCheck), ('MissingSlotDepCheck', metadata.MissingSlotDepCheck), ('MissingUnpackerDepCheck', metadata.MissingUnpackerDepCheck), ('RequiredUSEMetadataCheck', metadata.RequiredUSEMetadataCheck), ('RestrictTestCheck', metadata.RestrictTestCheck), ('RestrictsCheck', metadata.RestrictsCheck), ('SrcUriCheck', metadata.SrcUriCheck), ('CategoryMetadataXmlCheck', metadata_xml.CategoryMetadataXmlCheck), ('PackageMetadataXmlCheck', metadata_xml.PackageMetadataXmlCheck), ('FetchablesUrlCheck', network.FetchablesUrlCheck), ('HomepageUrlCheck', network.HomepageUrlCheck), ('UnusedInMastersCheck', overlays.UnusedInMastersCheck), ('EqualVersionsCheck', pkgdir.EqualVersionsCheck), ('PkgDirCheck', pkgdir.PkgDirCheck), ('ProfilesCheck', profiles.ProfilesCheck), ('RepoProfilesCheck', profiles.RepoProfilesCheck), ('PythonCheck', python.PythonCheck), ('RepoDirCheck', repo.RepoDirCheck), ('GlobalUSECheck', repo_metadata.GlobalUSECheck), ('LicenseGroupsCheck', repo_metadata.LicenseGroupsCheck), ('ManifestCheck', repo_metadata.ManifestCheck), ('ManifestConflictCheck', repo_metadata.ManifestConflictCheck), ('PackageUpdatesCheck', repo_metadata.PackageUpdatesCheck), ('UnusedEclassesCheck', repo_metadata.UnusedEclassesCheck), ('UnusedLicensesCheck', repo_metadata.UnusedLicensesCheck), ('UnusedMirrorsCheck', repo_metadata.UnusedMirrorsCheck), ('StableRequestCheck', stablereq.StableRequestCheck), ('UnstableOnlyCheck', unstable_only.UnstableOnlyCheck), ('VisibilityCheck', visibility.VisibilityCheck), ('WhitespaceCheck', whitespace.WhitespaceCheck))
TRANSFORMS = (('CategoryToRepo', feeds.CategoryToRepo), ('EbuildToVersion', feeds.EbuildToVersion), ('PackageToCategory', feeds.PackageToCategory), ('PackageToRepo', feeds.PackageToRepo), ('RawVersionToCategory', feeds.RawVersionToCategory), ('RawVersionToRawPackage', feeds.RawVersionToRawPackage), ('VersionToCategory', feeds.VersionToCategory), ('VersionToEbuild', feeds.VersionToEbuild), ('VersionToPackage', feeds.VersionToPackage))
REPORTERS = (('BinaryPickleStream', reporters.BinaryPickleStream), ('CsvReporter', reporters.CsvReporter), ('FancyReporter', reporters.FancyReporter), ('FormatReporter', reporters.FormatReporter), ('JsonReporter', reporters.JsonReporter), ('JsonStream', reporters.JsonStream), ('NullReporter', reporters.NullReporter), ('PickleStream', reporters.PickleStream), ('StrReporter', reporters.StrReporter), ('XmlReporter', reporters.XmlReporter))
